@@ -6,6 +6,10 @@ test_that("lake_wiki works", {
 
   expect_false(is.na(lake_wiki("Lake Mendota")$`Max. depth`))
   expect_false(is.na(lake_wiki("Trout Lake (Wisconsin)")$`Max. depth`))
+
+  # Lake pages with multiple info boxes
+  expect_false(is.na(lake_wiki("Acton Lake")$`Surface area`))
+
 })
 
 test_that("simple redirects work", {
@@ -14,3 +18,11 @@ test_that("simple redirects work", {
 
   expect_false(is.na(lake_wiki("Lake George (Michigan-Ontario)")$Name))
 })
+
+# test_that("lake_wiki fails well", {
+#   skip_on_cran()
+#   skip_on_travis()
+#
+#   expect_error(lake_wiki("Lake Bamboozle"), NA)
+#
+# })
